Package: MetaGxOvarian
Type: Package
Title: Transcriptomic Ovarian Cancer Datasets
Version: 1.32.0
Date: `r Sys.date()`
Authors@R: c(
    person("Michael", "Zon", role=c("aut"), 
        email='michaelzon7@gmail.com'), 
    person('Vandana', 'Sandhu', role=c("aut"), email='vsandhu1987@gmail.com'),
    person('Christopher', 'Eeles', role=c('ctb'), 
        email='christopher.eeles@uhnresearch.ca'),
    person('Benjamin', 'Haibe-Kains', role=c("aut", "cre"),
        email='benjamin.haibe.kains@utoronto.ca'))
Description: A collection of Ovarian Cancer Transcriptomic Datasets that are 
    part of the MetaGxData package compendium. 
License: Artistic-2.0
Depends: Biobase, AnnotationHub, ExperimentHub, SummarizedExperiment, R
        (>= 3.6.0)
Imports: stats, lattice, impute
Suggests: testthat, xtable, rmarkdown, knitr, BiocStyle, markdown
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: no
biocViews: ExpressionData, ExperimentHub, CancerData,
        Homo_sapiens_Data, ArrayExpress, GEO, NCI, MicroarrayData,
        ExperimentData
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/MetaGxOvarian
git_branch: RELEASE_3_23
git_last_commit: 80b9a0e
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
Packaged: 2026-05-05 15:31:13 UTC; biocbuild
Author: Michael Zon [aut],
  Vandana Sandhu [aut],
  Christopher Eeles [ctb],
  Benjamin Haibe-Kains [aut, cre]
Maintainer: Benjamin Haibe-Kains <benjamin.haibe.kains@utoronto.ca>
