MetaGxOvarian
========

ExperimentalHubData package containing 26 ovarian cancer datasets


Installation
========

The package can be installed by running the below two lines

if (!requireNamespace("BiocManager", quietly=TRUE))
    install.packages("BiocManager")

BiocManager::install("MetaGxOvarian")
