

#As numerous functions are required to create the curated datasets from scratch and the steps required to do so have been
#outlined by Levi Waldron, users are referred to https://bitbucket.org/lwaldron/curatedovariandata/overview in order
#to reproduce 21 of the 26 datasets.

#This package is essentially an update of the curatedOvarianData package which contains 21 datasets. 5 datasets have
#been added to MetaGxOvarian that were not present in curatedOvarianData. Information regarding the processing of the data
#can be found in Waldron et al's paper curatedOvarianData: clinically annotated data for the ovarian cancer transcriptome.
#Some additional information, such as the clinical data available for each dataset, can be found in the manuscript devoted
#to the MetaGxData packages, MetaGxData: Breast and Ovarian Clinically Annotated Transcriptomics Datasets

#createEsets.R script and patientselection.config scripts are available with the package in order to filter the data
#and remove duplicate samples as described in the manuscript devoted to the MetaGxData



