\name{ GSE6822 }
\alias{ GSE6822 }
\docType{data}
\title{ Classification of ovarian tumor samples }
\description{ Ouellet V, Provencher DM, Maugard CM, Le Page C, Ren F, Lussier C, Novak J, Ge B, Hudson TJ, Tonin PN, Mes-Masson A-M: Discrimination between serous low malignant potential and invasive epithelial ovarian tumors using molecular profiling. Oncogene 2005, 24:4672-4687. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Ouellet V, Provencher DM, Maugard CM, Le Page C, Ren F, Lussier C, Novak J, Ge B, Hudson TJ, Tonin PN, Mes-Masson A-M: Discrimination between serous low malignant potential and invasive epithelial ovarian tumors using molecular profiling. Oncogene 2005, 24:4672-4687.
  Laboratory: Ouellet, Mes-Masson 2005
  Contact information:
  Title: Classification of ovarian tumor samples
  URL:
  PMIDs: PMID unknown

  Abstract: A 40 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      [Hu6800] Affymetrix Human Full Length HuGeneFL Array
   platform_shorttitle:
      Affymetrix Hu6800
   platform_summary:
      hu6800
   platform_manufacturer:
      Affymetrix
   platform_distribution:
      commercial
   platform_accession:
      GPL80
   version:
      2015-09-22 20:07:22

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: A28102_at AB000114_at ... Z97074_at (6407 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 6407 features, 66 samples
Platform type:
---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
Ovarian tumor AM053 Ovarian tumor AM122 Ovarian tumor AM124 Ovarian tumor AM125
                  1                   1                   1                   1
Ovarian tumor AM127 Ovarian tumor AM137 Ovarian tumor AM138 Ovarian tumor AM144
                  1                   1                   1                   1
Ovarian tumor AM178 Ovarian tumor AM179 Ovarian tumor AM182 Ovarian tumor AM195
                  1                   1                   1                   1
Ovarian tumor AM196 Ovarian tumor AM198 Ovarian tumor AM200 Ovarian tumor AM201
                  1                   1                   1                   1
Ovarian tumor AM202 Ovarian tumor AM203 Ovarian tumor AM204 Ovarian tumor AM207
                  1                   1                   1                   1
Ovarian tumor AM208 Ovarian tumor AM209 Ovarian tumor AM225 Ovarian tumor AM226
                  1                   1                   1                   1
Ovarian tumor AM228 Ovarian tumor AM233 Ovarian tumor AM250 Ovarian tumor AM252
                  1                   1                   1                   1
Ovarian tumor AM253 Ovarian tumor AM255 Ovarian tumor AM256 Ovarian tumor AM259
                  1                   1                   1                   1
Ovarian tumor AM261 Ovarian tumor AM263 Ovarian tumor AM268 Ovarian tumor AM269
                  1                   1                   1                   1
Ovarian tumor AM287 Ovarian tumor AM288 Ovarian tumor AM289 Ovarian tumor AM290
                  1                   1                   1                   1
Ovarian tumor AM292 Ovarian tumor AM293 Ovarian tumor AM294 Ovarian tumor AM311
                  1                   1                   1                   1
Ovarian tumor AM313 Ovarian tumor AM315 Ovarian tumor AM317 Ovarian tumor AM333
                  1                   1                   1                   1
Ovarian tumor AM335 Ovarian tumor AM339 Ovarian tumor AM341 Ovarian tumor AM344
                  1                   1                   1                   1
Ovarian tumor AM345 Ovarian tumor AM347 Ovarian tumor AM348 Ovarian tumor AM349
                  1                   1                   1                   1
Ovarian tumor AM354 Ovarian tumor AM364 Ovarian tumor AM367 Ovarian tumor AM368
                  1                   1                   1                   1
Ovarian tumor AM381 Ovarian tumor AM382 Ovarian tumor AM398 Ovarian tumor AM429
                  1                   1                   1                   1
Ovarian tumor AM431 Ovarian tumor AM438
                  1                   1

sample_type:
tumor
   66

histological_type:
       clearcell             endo              mix         mucinous
              11                7                3                1
             ser undifferentiated
              41                3

primarysite:
ov
66

summarygrade:
high  low NA's
  40   15   11

grade:
   1    2    3 NA's
   1   14   40   11

batch:
2000-12-21 2001-05-03 2001-05-29 2001-06-12 2001-09-25 2001-09-26 2001-09-27
         1          1          3          3          1          5          8
2002-02-14 2002-04-17 2002-04-18 2002-07-18 2002-07-24 2002-10-20 2002-10-30
         4          1          9          7          4         10          5
2002-11-01 2002-11-13
         2          2

uncurated_author_metadata:
                                       title: Ovarian tumor AM053///geo_accession: GSM157229///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157229/GSM157229.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian tumor AM122///geo_accession: GSM157231///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3, potentially from extra-ovarian origin///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157231/GSM157231.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM124///geo_accession: GSM157232///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157232/GSM157232.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM125///geo_accession: GSM157233///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157233/GSM157233.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian tumor AM127///geo_accession: GSM157234///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3, post-chemotherapy sample///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157234/GSM157234.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: Ovarian tumor AM137///geo_accession: GSM157238///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157238/GSM157238.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: Ovarian tumor AM138///geo_accession: GSM157239///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157239/GSM157239.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM144///geo_accession: GSM157240///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157240/GSM157240.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM178///geo_accession: GSM157241///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157241/GSM157241.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: Ovarian tumor AM179///geo_accession: GSM157242///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157242/GSM157242.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM182///geo_accession: GSM157243///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157243/GSM157243.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM195///geo_accession: GSM157244///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157244/GSM157244.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: Ovarian tumor AM196///geo_accession: GSM157245///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157245/GSM157245.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM198///geo_accession: GSM157246///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157246/GSM157246.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM200///geo_accession: GSM157247///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157247/GSM157247.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM201///geo_accession: GSM157248///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157248/GSM157248.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM202///geo_accession: GSM157249///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157249/GSM157249.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM203///geo_accession: GSM157250///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157250/GSM157250.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM204///geo_accession: GSM157251///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157251/GSM157251.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM207///geo_accession: GSM157252///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157252/GSM157252.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM208///geo_accession: GSM157253///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157253/GSM157253.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM209///geo_accession: GSM157254///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157254/GSM157254.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: Ovarian tumor AM225///geo_accession: GSM157255///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: benign///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157255/GSM157255.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: Ovarian tumor AM226///geo_accession: GSM157256///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: benign///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157256/GSM157256.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: Ovarian tumor AM228///geo_accession: GSM157257///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: benign///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157257/GSM157257.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: Ovarian tumor AM233///geo_accession: GSM157258///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: benign///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157258/GSM157258.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                        title: Ovarian tumor AM250///geo_accession: GSM157259///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: mixed, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157259/GSM157259.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM252///geo_accession: GSM157260///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157260/GSM157260.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: Ovarian tumor AM253///geo_accession: GSM157261///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157261/GSM157261.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM255///geo_accession: GSM157262///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157262/GSM157262.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM256///geo_accession: GSM157263///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157263/GSM157263.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                               title: Ovarian tumor AM259///geo_accession: GSM157264///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: microinvasion of grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157264/GSM157264.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM261///geo_accession: GSM157265///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157265/GSM157265.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM263///geo_accession: GSM157266///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157266/GSM157266.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM268///geo_accession: GSM157267///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157267/GSM157267.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM269///geo_accession: GSM157268///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157268/GSM157268.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian tumor AM287///geo_accession: GSM157269///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: undetermined, Tumor stage: invasive, small foci of grade 3 tumor///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157269/GSM157269.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian tumor AM288///geo_accession: GSM157270///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: undetermined, Tumor stage: invasive, small foci of grade 3 tumor///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157270/GSM157270.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM289///geo_accession: GSM157271///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157271/GSM157271.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM290///geo_accession: GSM157272///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157272/GSM157272.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian tumor AM292///geo_accession: GSM157273///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: undetermined, Tumor stage: invasive, small foci of grade 3 tumor///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157273/GSM157273.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM293///geo_accession: GSM157274///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157274/GSM157274.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM294///geo_accession: GSM157275///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157275/GSM157275.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: Ovarian tumor AM311///geo_accession: GSM157276///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 1///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157276/GSM157276.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                     title: Ovarian tumor AM313///geo_accession: GSM157277///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2/3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157277/GSM157277.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                     title: Ovarian tumor AM315///geo_accession: GSM157278///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2/3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157278/GSM157278.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM317///geo_accession: GSM157279///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157279/GSM157279.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM333///geo_accession: GSM157280///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157280/GSM157280.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM335///geo_accession: GSM157281///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157281/GSM157281.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM339///geo_accession: GSM157282///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157282/GSM157282.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                      title: Ovarian tumor AM341///geo_accession: GSM157283///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: mixed, Tumor stage: invasive grade 2/3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157283/GSM157283.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                  title: Ovarian tumor AM344///geo_accession: GSM157284///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: benign///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157284/GSM157284.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM345///geo_accession: GSM157285///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157285/GSM157285.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian tumor AM347///geo_accession: GSM157286///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2, post-chemotherapy sample///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157286/GSM157286.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM348///geo_accession: GSM157287///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157287/GSM157287.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM349///geo_accession: GSM157288///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157288/GSM157288.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                   title: Ovarian tumor AM354///geo_accession: GSM157289///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157289/GSM157289.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                            title: Ovarian tumor AM364///geo_accession: GSM157290///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: mucinous, Tumor stage: borderline///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: low malignant potential///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157290/GSM157290.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM367///geo_accession: GSM157291///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157291/GSM157291.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM368///geo_accession: GSM157292///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157292/GSM157292.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM381///geo_accession: GSM157293///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157293/GSM157293.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM382///geo_accession: GSM157294///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157294/GSM157294.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian tumor AM398///geo_accession: GSM157295///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: endometrioid, Tumor stage: invasive grade 3, xenograft of an EOC cell line///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157295/GSM157295.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
    title: Ovarian tumor AM429///geo_accession: GSM157296///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: clear cell, Tumor stage: invasive grade 3, xenograft of an EOC cell line///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157296/GSM157296.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Ovarian tumor AM431///geo_accession: GSM157297///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: serous, Tumor stage: invasive grade 2///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157297/GSM157297.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                        title: Ovarian tumor AM438///geo_accession: GSM157298///status: Public on Dec 31 2007///submission_date: Jan 22 2007///last_update_date: Feb 25 2008///type: RNA///channel_count: 1///source_name_ch1: epithelian ovarian tumor///organism_ch1: Homo sapiens///characteristics_ch1: Tissue: epithelial ovarian tumor, Tumor type: mixed, Tumor stage: invasive grade 3///molecule_ch1: total RNA///extract_protocol_ch1: Trizol extraction of total RNA was performed according to the manufacturer's instructions.///label_ch1: Biotin///label_protocol_ch1: Biotinylated cRNA were prepared according to the standard Affymetrix protocol from 15 microg total RNA.///taxid_ch1: 9606///hyb_protocol: 15ug of total RNA was reverse-transcribed with oligo-dT primer containing a T7 RNA polymerase-binding site. An in vitro transcription was performed on this cDNA. DNA from the samples was fragmented in 40 mM Tris acetate, 100 mM potassium acetate, and 30 mM MgCl2 (pH 8.1) at 95C to reduce secondary structures. 15 ug of cRNA were hybridized to an Affymetrix HuGeneFL microarray, washed and stained.///scan_protocol: Scanned with a Hewlett Packard Gene Array Scanner///description: invasive///data_processing: Raw values assigned by MAS 4///platform_id: GPL80///contact_name: Jaroslav,Petr,Novak///contact_email: jaroslav.novak@mail.mcgill.ca, jaroslav.novak@gmail.com///contact_phone: 450-465-1383///contact_fax: 450-465-3033///contact_department: Microarray Platform///contact_institute: McGill University and Genome Quebec Innovation Centre///contact_address: 740, Dr Penfield Avenue///contact_city: Montreal///contact_state: Quebec///contact_zip.postal_code: H3A 1A4///contact_country: Canada///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM157nnn/GSM157298/GSM157298.CEL.gz///data_row_count: 7129
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

duplicates:
   Length     Class      Mode
       66 character character

}}
\keyword{datasets}
