\name{ GSE12470 }
\alias{ GSE12470 }
\docType{data}
\title{ Gene expression profiling of advanced-stage serous ovarian cancers distinguishes novel subclasses and implicates ZEB2 in tumor progression and prognosis. }
\description{ To elucidate the mechanisms of rapid progression of serous ovarian cancer, gene expression profiles from 43 ovarian cancer tissues comprising eight early stage and 35 advanced stage tissues were carried out using oligonucleotide microarrays of 18,716 genes. By non-negative matrix factorization analysis using 178 genes, which were extracted as stage-specific genes, 35 advanced stage cases were classified into two subclasses with superior (n = 17) and poor (n = 18) outcome evaluated by progression-free survival (log rank test, P = 0.03). Of the 178 stage-specific genes, 112 genes were identified as showing different expression between the two subclasses. Of the 48 genes selected for biological function by gene ontology analysis or Ingenuity Pathway Analysis, five genes (ZEB2, CDH1, LTBP2, COL16A1, and ACTA2) were extracted as candidates for prognostic factors associated with progression-free survival. The relationship between high ZEB2 or low CDH1 expression and shorter progression-free survival was validated by real-time RT-PCR experiments of 37 independent advanced stage cancer samples. ZEB2 expression was negatively correlated with CDH1 expression in advanced stage samples, whereas ZEB2 knockdown in ovarian adenocarcinoma SKOV3 cells resulted in an increase in CDH1 expression. Multivariate analysis showed that high ZEB2 expression was independently associated with poor prognosis. Furthermore, the prognostic effect of E-cadherin encoded by CDH1 was verified using immunohistochemical analysis of an independent advanced stage cancer samples set (n = 74). These findings suggest that the expression of epithelial-mesenchymal transition-related genes such as ZEB2 and CDH1 may play important roles in the invasion process of advanced stage serous ovarian cancer. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Yoshihara K, Tajima A, Komata D, Yamamoto T, Kodama S, Fujiwara H, Suzuki M, Onishi Y, Hatae M, Sueyoshi K, Fujiwara H, Kudo Y, Inoue I, Tanaka K.Gene expression profiling of advanced-stage serous ovarian cancers distinguishes novel subclasses and implicates ZEB2 in tumor progression and prognosis. Cancer Sci. 2009 Aug; 100(8):1421-8.
  Laboratory: Yoshihara, Tanaka 2009
  Contact information:
  Title: Gene expression profiling of advanced-stage serous ovarian cancers distinguishes novel subclasses and implicates ZEB2 in tumor progression and prognosis.
  URL:
  PMIDs: 19486012

  Abstract: A 253 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      Agilent-012097 Human 1A Microarray (V2) G4110B (Feature Number version)
   platform_shorttitle:
      Agilent G4110B
   platform_summary:
      hgug4110b
   platform_manufacturer:
      Agilent
   platform_distribution:
      commercial
   platform_accession:
      GPL887
   version:
      2015-09-22 19:08:17

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 3 5 ... 22571 (15999 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 15999 features, 53 samples
Platform type:
---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
Advanced serous ovarian cancer 10 Advanced serous ovarian cancer 11
                                1                                 1
Advanced serous ovarian cancer 15 Advanced serous ovarian cancer 17
                                1                                 1
Advanced serous ovarian cancer 18  Advanced serous ovarian cancer 2
                                1                                 1
Advanced serous ovarian cancer 20 Advanced serous ovarian cancer 23
                                1                                 1
Advanced serous ovarian cancer 24 Advanced serous ovarian cancer 25
                                1                                 1
Advanced serous ovarian cancer 27 Advanced serous ovarian cancer 36
                                1                                 1
Advanced serous ovarian cancer 37 Advanced serous ovarian cancer 38
                                1                                 1
Advanced serous ovarian cancer 39 Advanced serous ovarian cancer 42
                                1                                 1
Advanced serous ovarian cancer 43 Advanced serous ovarian cancer 45
                                1                                 1
Advanced serous ovarian cancer 46 Advanced serous ovarian cancer 49
                                1                                 1
Advanced serous ovarian cancer 50 Advanced serous ovarian cancer 51
                                1                                 1
Advanced serous ovarian cancer 52 Advanced serous ovarian cancer 53
                                1                                 1
Advanced serous ovarian cancer 54 Advanced serous ovarian cancer 55
                                1                                 1
Advanced serous ovarian cancer 56 Advanced serous ovarian cancer 57
                                1                                 1
Advanced serous ovarian cancer 58  Advanced serous ovarian cancer 6
                                1                                 1
Advanced serous ovarian cancer 60 Advanced serous ovarian cancer 61
                                1                                 1
Advanced serous ovarian cancer 62 Advanced serous ovarian cancer 64
                                1                                 1
 Advanced serous ovarian cancer 7    Early serous ovarian cancer 28
                                1                                 1
   Early serous ovarian cancer 32    Early serous ovarian cancer 33
                                1                                 1
   Early serous ovarian cancer 35     Early serous ovarian cancer 5
                                1                                 1
   Early serous ovarian cancer 65     Early serous ovarian cancer 8
                                1                                 1
    Early serous ovarian cancer 9              Peritoneum normal 12
                                1                                 1
             Peritoneum normal 15              Peritoneum normal 16
                                1                                 1
             Peritoneum normal 18              Peritoneum normal 21
                                1                                 1
             Peritoneum normal 23               Peritoneum normal 3
                                1                                 1
             Peritoneum normal 30               Peritoneum normal 4
                                1                                 1
              Peritoneum normal 7
                                1

sample_type:
healthy   tumor
     10      43

histological_type:
 ser NA's
  43   10

primarysite:
ov
53

summarystage:
early  late  NA's
    8    35    10

tumorstage:
   1 NA's
   8   45

uncurated_author_metadata:
  title: Advanced serous ovarian cancer 10///geo_accession: GSM312155///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-10///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312155/GSM312155_s10.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 11///geo_accession: GSM312141///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-11///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312141/GSM312141_s11.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 15///geo_accession: GSM312156///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-15///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312156/GSM312156_s15.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 17///geo_accession: GSM312142///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-17///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312142/GSM312142_s17.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 18///geo_accession: GSM312143///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-18///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312143/GSM312143_s18.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 20///geo_accession: GSM312144///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-20///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312144/GSM312144_s20.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 23///geo_accession: GSM312157///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-23///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312157/GSM312157_s23.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 24///geo_accession: GSM312145///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-24///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312145/GSM312145_s24.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 25///geo_accession: GSM312146///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-25///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312146/GSM312146_s25.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 27///geo_accession: GSM312158///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-27///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312158/GSM312158_s27.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Advanced serous ovarian cancer 2///geo_accession: GSM312138///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-2///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312138/GSM312138_s2.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 36///geo_accession: GSM312147///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-36///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312147/GSM312147_s36.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 37///geo_accession: GSM312148///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-37///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312148/GSM312148_s37.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 38///geo_accession: GSM312149///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-38///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312149/GSM312149_s38.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 39///geo_accession: GSM312159///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-39///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312159/GSM312159_s39.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 42///geo_accession: GSM312160///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-42///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312160/GSM312160_s42.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 43///geo_accession: GSM312150///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-43///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312150/GSM312150_s43.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 45///geo_accession: GSM312161///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-45///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312161/GSM312161_s45.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 46///geo_accession: GSM312162///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-46///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312162/GSM312162_s46.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 49///geo_accession: GSM312151///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-49///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312151/GSM312151_s49.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 50///geo_accession: GSM312163///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-50///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312163/GSM312163_s50.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 51///geo_accession: GSM312165///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-51///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312165/GSM312165_s51.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 52///geo_accession: GSM312167///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-52///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312167/GSM312167_s52.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 53///geo_accession: GSM312168///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-53///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312168/GSM312168_s53.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 54///geo_accession: GSM312152///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-54///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312152/GSM312152_s54.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Advanced serous ovarian cancer 55///geo_accession: GSM312170///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-55///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312170/GSM312170_1_s55.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 56///geo_accession: GSM312171///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-56///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312171/GSM312171_s56.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 57///geo_accession: GSM312153///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-54///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312153/GSM312153_s57.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 58///geo_accession: GSM312172///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-58///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312172/GSM312172_s58.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 60///geo_accession: GSM312173///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-60///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312173/GSM312173_s60.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 61///geo_accession: GSM312154///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-61///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312154/GSM312154_s61.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 62///geo_accession: GSM312174///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-62///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312174/GSM312174_s62.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Advanced serous ovarian cancer 64///geo_accession: GSM312175///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-64///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312175/GSM312175_s64.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Advanced serous ovarian cancer 6///geo_accession: GSM312139///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-6///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312139/GSM312139_s6.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Advanced serous ovarian cancer 7///geo_accession: GSM312140///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: advanced stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-7///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312140/GSM312140_s7.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Early serous ovarian cancer 28///geo_accession: GSM312180///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-28///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312180/GSM312180_s28.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Early serous ovarian cancer 32///geo_accession: GSM312181///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-32///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312181/GSM312181_s32.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Early serous ovarian cancer 33///geo_accession: GSM312182///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-33///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312182/GSM312182_s33.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Early serous ovarian cancer 35///geo_accession: GSM312183///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-35///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312183/GSM312183_s35.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: Early serous ovarian cancer 5///geo_accession: GSM312176///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cacner///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-5///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312176/GSM312176_s5.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
        title: Early serous ovarian cancer 65///geo_accession: GSM312185///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-65///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312185/GSM312185_s65.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: Early serous ovarian cancer 8///geo_accession: GSM312178///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-8///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312178/GSM312178_s8.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
           title: Early serous ovarian cancer 9///geo_accession: GSM312179///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: serous ovarian cancer///characteristics_ch1.2: Stage: early stage///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Serous ovarian cancer-9///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312179/GSM312179_s9.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 12///geo_accession: GSM312131///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-12///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312131/GSM312131_p12.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 15///geo_accession: GSM312132///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-15///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312132/GSM312132_p15.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 16///geo_accession: GSM312133///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-16///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312133/GSM312133_p16.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 18///geo_accession: GSM312134///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-18///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312134/GSM312134_p18.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 21///geo_accession: GSM312135///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-21///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312135/GSM312135_p21.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                       title: Peritoneum normal 23///geo_accession: GSM312136///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-23///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312136/GSM312136_1_p23.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                         title: Peritoneum normal 30///geo_accession: GSM312137///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-30///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312137/GSM312137_s30.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: Peritoneum normal 3///geo_accession: GSM311992///status: Public on Jul 19 2009///submission_date: Aug 12 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-3///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM311nnn/GSM311992/GSM311992_p3.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: Peritoneum normal 4///geo_accession: GSM312129///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-4///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312129/GSM312129_p4.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                            title: Peritoneum normal 7///geo_accession: GSM312130///status: Public on Jul 19 2009///submission_date: Aug 13 2008///last_update_date: Jul 19 2009///type: RNA///channel_count: 1///source_name_ch1: normal peritoneum///organism_ch1: Homo sapiens///characteristics_ch1: Gender: female///characteristics_ch1.1: Tissue: normal peritoneum///characteristics_ch1.2: ///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue sample using TRIzol reagent (Invitrogen, Carlsbad, CA, USA), and examined with 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Five hundred nanograms of total RNA were converted into labeled cRNA with nucleotides coupled to a cyanine 3-CTP (Cy3) (PerkinElmer, Boston, MA, USA) using the Low RNA Input Fluorescent Linear Amplification Kit (Agilent Technologies). ///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.5 g) were hybridized for 17 hours at 65 degrees Celsius to an Agilent Human 1A (v2) Oligo Microarray.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///description: Peritoneum-Normal-7///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver8.5 (Agilent Technologies) in the default settings.///platform_id: GPL887///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM312nnn/GSM312130/GSM312130_p7.txt.gz///data_row_count: 22153
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

duplicates:
GSE12470.GSE12470_GSM312135 GSE12470.GSE12470_GSM312136
                          1                           1
GSE12470.GSE12470_GSM312145 GSE12470.GSE12470_GSM312146
                          1                           1
                       NA's
                         49

}}
\keyword{datasets}
