\name{ GSE19829 }
\alias{ GSE19829 }
\docType{data}
\title{ Gene expression profile of BRCAness that correlates with responsiveness to chemotherapy and with outcome in patients with epithelial ovarian cancer. }
\description{ To define a gene expression profile of BRCAness that correlates with chemotherapy response and outcome in epithelial ovarian cancer (EOC).A publicly available microarray data set including 61 patients with EOC with either sporadic disease or BRCA(1/2) germline mutations was used for development of the BRCAness profile. Correlation with platinum responsiveness was assessed in platinum-sensitive and platinum-resistant tumor biopsy specimens from six patients with BRCA germline mutations. Association with poly-ADP ribose polymerase (PARP) inhibitor responsiveness and with radiation-induced RAD51 foci formation (a surrogate of homologous recombination) was assessed in Capan-1 cell line clones. The BRCAness profile was validated in 70 patients enriched for sporadic disease to assess its association with outcome.The BRCAness profile accurately predicted platinum responsiveness in eight out of 10 patient-derived tumor specimens, and between PARP-inhibitor sensitivity and resistance in four out of four Capan-1 clones. [corrected] When applied to the 70 patients with sporadic disease, patients with the BRCA-like (BL) profile had improved disease-free survival (34 months v 15 months; log-rank P = .013) and overall survival (72 months v 41 months; log-rank P = .006) compared with patients with a non-BRCA-like (NBL) profile, respectively. The BRCAness profile maintained independent prognostic value in multivariate analysis, which controlled for other known clinical prognostic factors.The BRCAness profile correlates with responsiveness to platinum and PARP inhibitors and identifies a subset of sporadic patients with improved outcome. Additional evaluation of this profile as a predictive tool in patients with sporadic EOC is warranted. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Konstantinopoulos PA, Spentzos D, Karlan BY, Taniguchi T et al. Gene expression profile of BRCAness that correlates with responsiveness to chemotherapy and with outcome in patients with epithelial ovarian cancer. J Clin Oncol 2010 Aug 1;28(22):3555-61.
  Laboratory: Konstantinopoulos, Cannistra 2010 hgu95
  Contact information:
  Title: Gene expression profile of BRCAness that correlates with responsiveness to chemotherapy and with outcome in patients with epithelial ovarian cancer.
  URL:
  PMIDs: 20547991

  Abstract: A 241 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      [HG_U95Av2] Affymetrix Human Genome U95 Version 2 Array
   platform_shorttitle:
      Affymetrix HG_U95Av2
   platform_summary:
      hgu95av2
   platform_manufacturer:
      Affymetrix
   platform_distribution:
      commercial
   platform_accession:
      GPL570|GPL8300
   version:
      2015-09-22 19:26:29

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: 1007_s_at 1053_at ... AFFX-MurIL4_at (54253 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 54253 features, 70 samples
Platform type:
Overall survival time-to-event summary (in years):
Call: survfit(formula = Surv(time, cens) ~ -1)

      n  events  median 0.95LCL 0.95UCL
  70.00   40.00    3.78    2.96    5.92

---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
 Ovarian cancer_sample 1 Ovarian cancer_sample 10 Ovarian cancer_sample 11
                       1                        1                        1
Ovarian cancer_sample 12 Ovarian cancer_sample 13 Ovarian cancer_sample 14
                       1                        1                        1
Ovarian cancer_sample 15 Ovarian cancer_sample 16 Ovarian cancer_sample 17
                       1                        1                        1
Ovarian cancer_sample 18 Ovarian cancer_sample 19  Ovarian cancer_sample 2
                       1                        1                        1
Ovarian cancer_sample 20 Ovarian cancer_sample 21 Ovarian cancer_sample 22
                       1                        1                        1
Ovarian cancer_sample 23 Ovarian cancer_sample 24 Ovarian cancer_sample 25
                       1                        1                        1
Ovarian cancer_sample 26 Ovarian cancer_sample 27 Ovarian cancer_sample 28
                       1                        1                        1
Ovarian cancer_sample 29  Ovarian cancer_sample 3 Ovarian cancer_sample 30
                       1                        1                        1
Ovarian cancer_sample 31 Ovarian cancer_sample 32 Ovarian cancer_sample 33
                       1                        1                        1
Ovarian cancer_sample 34 Ovarian cancer_sample 35 Ovarian cancer_sample 36
                       1                        1                        1
Ovarian cancer_sample 37 Ovarian cancer_sample 38 Ovarian cancer_sample 39
                       1                        1                        1
 Ovarian cancer_sample 4 Ovarian cancer_sample 40 Ovarian cancer_sample 41
                       1                        1                        1
Ovarian cancer_sample 42 Ovarian cancer_sample 43 Ovarian cancer_sample 44
                       1                        1                        1
Ovarian cancer_sample 45 Ovarian cancer_sample 46 Ovarian cancer_sample 47
                       1                        1                        1
Ovarian cancer_sample 48 Ovarian cancer_sample 49  Ovarian cancer_sample 5
                       1                        1                        1
Ovarian cancer_sample 50 Ovarian cancer_sample 51 Ovarian cancer_sample 52
                       1                        1                        1
Ovarian cancer_sample 53 Ovarian cancer_sample 54 Ovarian cancer_sample 55
                       1                        1                        1
Ovarian cancer_sample 56 Ovarian cancer_sample 57 Ovarian cancer_sample 58
                       1                        1                        1
Ovarian cancer_sample 59  Ovarian cancer_sample 6 Ovarian cancer_sample 60
                       1                        1                        1
Ovarian cancer_sample 61 Ovarian cancer_sample 62 Ovarian cancer_sample 63
                       1                        1                        1
Ovarian cancer_sample 64 Ovarian cancer_sample 65 Ovarian cancer_sample 66
                       1                        1                        1
Ovarian cancer_sample 67 Ovarian cancer_sample 68 Ovarian cancer_sample 69
                       1                        1                        1
 Ovarian cancer_sample 7 Ovarian cancer_sample 70  Ovarian cancer_sample 8
                       1                        1                        1
 Ovarian cancer_sample 9
                       1

batch:
2001-09-14 2001-12-14 2002-08-20 2003-09-09 2003-09-18 2009-08-14
         7          4         14         13          4         28

days_to_death:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
   30.0   667.5  1125.0  1170.0  1522.0  3450.0

primarysite:
ov
70

sample_type:
tumor
   70

uncurated_author_metadata:
            title: Ovarian cancer_sample 10///geo_accession: GSM495148///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 37///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081437///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495148/GSM495148.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 11///geo_accession: GSM495149///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 54///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081438///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495149/GSM495149.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 12///geo_accession: GSM495150///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 63///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081439///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495150/GSM495150.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 13///geo_accession: GSM495151///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 18///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081440///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495151/GSM495151.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 14///geo_accession: GSM495152///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 72///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081441///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495152/GSM495152.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 15///geo_accession: GSM495153///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 72///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081442///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495153/GSM495153.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 16///geo_accession: GSM495154///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 10///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081443///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495154/GSM495154.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 17///geo_accession: GSM495155///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 32///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081444///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495155/GSM495155.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 18///geo_accession: GSM495156///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 48///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081445///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495156/GSM495156.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 19///geo_accession: GSM495157///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 63///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081446///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495157/GSM495157.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian cancer_sample 1///geo_accession: GSM495139///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 18///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081427///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495139/GSM495139.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 20///geo_accession: GSM495158///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 41///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081447///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495158/GSM495158.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 21///geo_accession: GSM495159///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 45///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081448///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495159/GSM495159.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 22///geo_accession: GSM495160///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 29///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081449///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495160/GSM495160.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 23///geo_accession: GSM495161///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 20///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081450///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495161/GSM495161.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 24///geo_accession: GSM495162///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 14///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081451///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495162/GSM495162.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 25///geo_accession: GSM495163///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 33///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081453///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495163/GSM495163.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                title: Ovarian cancer_sample 26///geo_accession: GSM495164///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 114///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081455///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495164/GSM495164.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
            title: Ovarian cancer_sample 27///geo_accession: GSM495165///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 32///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081457///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495165/GSM495165.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                  title: Ovarian cancer_sample 28///geo_accession: GSM495166///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 9///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081458///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495166/GSM495166.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 29///geo_accession: GSM495167///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 36///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7A3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495167/GSM495167.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian cancer_sample 2///geo_accession: GSM495140///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 48///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081428///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495140/GSM495140.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 30///geo_accession: GSM495168///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 35///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7A4///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495168/GSM495168.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 31///geo_accession: GSM495169///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 41///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7A5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495169/GSM495169.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 32///geo_accession: GSM495170///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 1///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7A6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495170/GSM495170.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 33///geo_accession: GSM495171///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 28///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7A7///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495171/GSM495171.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 34///geo_accession: GSM495172///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 66///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95AV2 DS 7A9///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495172/GSM495172.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 35///geo_accession: GSM495173///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 48///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7B2///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495173/GSM495173.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 36///geo_accession: GSM495174///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 12///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7B3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495174/GSM495174.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 37///geo_accession: GSM495175///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 41///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7B5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495175/GSM495175.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 38///geo_accession: GSM495176///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 19///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7B8///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495176/GSM495176.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 39///geo_accession: GSM495177///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 25///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7B9///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495177/GSM495177.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 3///geo_accession: GSM495141///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 115///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081429///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495141/GSM495141.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 40///geo_accession: GSM495178///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 23///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7C2///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495178/GSM495178.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 41///geo_accession: GSM495179///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 16///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7C3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495179/GSM495179.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 42///geo_accession: GSM495180///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 22///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 082002 HGU95Av2 DS 7C4///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495180/GSM495180.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian cancer_sample 43///geo_accession: GSM495181///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 42///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14B2///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495181/GSM495181.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 44///geo_accession: GSM495182///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 58///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14B3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495182/GSM495182.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 45///geo_accession: GSM495183///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 59///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14B5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495183/GSM495183.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian cancer_sample 46///geo_accession: GSM495184///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 33///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14B6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495184/GSM495184.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 47///geo_accession: GSM495185///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 65///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14C2///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495185/GSM495185.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian cancer_sample 48///geo_accession: GSM495186///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 46///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14C3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495186/GSM495186.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 49///geo_accession: GSM495187///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 51///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14C6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495187/GSM495187.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                 title: Ovarian cancer_sample 4///geo_accession: GSM495142///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 100///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081430///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495142/GSM495142.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian cancer_sample 50///geo_accession: GSM495188///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 33///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14C8///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495188/GSM495188.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 51///geo_accession: GSM495189///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 51///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14C9///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495189/GSM495189.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 52///geo_accession: GSM495190///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 52///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14D1///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495190/GSM495190.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 53///geo_accession: GSM495191///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 50///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14D3///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495191/GSM495191.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: Ovarian cancer_sample 54///geo_accession: GSM495192///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 44///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14D5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495192/GSM495192.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: Ovarian cancer_sample 55///geo_accession: GSM495193///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 10///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 090903 HGU95AV2 TL 14D6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495193/GSM495193.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
   title: Ovarian cancer_sample 56///geo_accession: GSM495194///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 8///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC G4///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495194/GSM495194.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
   title: Ovarian cancer_sample 57///geo_accession: GSM495195///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 4///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC G5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495195/GSM495195.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 58///geo_accession: GSM495196///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 30///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC G6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495196/GSM495196.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian cancer_sample 59///geo_accession: GSM495197///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 52///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC G7///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495197/GSM495197.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian cancer_sample 5///geo_accession: GSM495143///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 15///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081431///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495143/GSM495143.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 60///geo_accession: GSM495198///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 50///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC G9///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495198/GSM495198.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian cancer_sample 61///geo_accession: GSM495199///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 68///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC H1///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495199/GSM495199.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 62///geo_accession: GSM495200///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 46///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091301 HGU95Av2 SC H2///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495200/GSM495200.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 63///geo_accession: GSM495201///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 44///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091803 HU95AV2 TL 15D4///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495201/GSM495201.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: Ovarian cancer_sample 64///geo_accession: GSM495202///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 12///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091803 HU95AV2 TL 15D6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495202/GSM495202.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 65///geo_accession: GSM495203///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 39///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091803 HU95AV2 TL 15D7///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495203/GSM495203.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
      title: Ovarian cancer_sample 66///geo_accession: GSM495204///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 38///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 091803 HU95AV2 TL 15D9///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495204/GSM495204.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 67///geo_accession: GSM495205///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 30///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 121401 HGU95Av2 SC R5///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495205/GSM495205.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 68///geo_accession: GSM495206///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 34///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 121401 HGU95Av2 SC R6///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495206/GSM495206.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: Ovarian cancer_sample 69///geo_accession: GSM495207///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 24///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 121401 HGU95Av2 SC R7///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495207/GSM495207.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian cancer_sample 6///geo_accession: GSM495144///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 11///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081432///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495144/GSM495144.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
       title: Ovarian cancer_sample 70///geo_accession: GSM495208///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 39///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: 121401 HGU95Av2 SC R8///data_processing: RMA///platform_id: GPL8300///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495208/GSM495208.CEL.gz///data_row_count: 12558
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                  title: Ovarian cancer_sample 7///geo_accession: GSM495145///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 54///characteristics_ch1.1: overall survival (censored): 0 [censored]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081434///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495145/GSM495145.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
             title: Ovarian cancer_sample 8///geo_accession: GSM495146///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 33///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081435///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495146/GSM495146.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
              title: Ovarian cancer_sample 9///geo_accession: GSM495147///status: Public on Jul 11 2010///submission_date: Jan 11 2010///last_update_date: Jul 11 2010///type: RNA///channel_count: 1///source_name_ch1: Ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: overall survival (months): 5///characteristics_ch1.1: overall survival (censored): 1 [event (death)]///molecule_ch1: total RNA///extract_protocol_ch1: RNA was isolated using the trizol protocol///label_ch1: biotin///label_protocol_ch1: RNA is converted into cDNA using a T7 promoter-tailed oligo-dT primer in the synthesis of the first cDNA strand; second strand cDNA synthesis is then carried out.///label_protocol_ch1.1: The double-stranded cDNA is used as the template in an in vitro transcription (IVT) reaction catalyzed by T7 polymerase and containing biotinylated CTP and UTP in addition to the four unmodified ribonucleoside triphosphates///taxid_ch1: 9606///hyb_protocol: Standard Affymetrix protocol.///scan_protocol: Standard Affymetrix protocol. Each cRNA bound at its complementary oligonucleotide is excited using a confocal laser scanner, and the positions and intensities of the fluorescent emissions are captured.///description: PK2009081436///data_processing: RMA///platform_id: GPL570///contact_name: panagiotis,,konstantinopoulos///contact_email: pkonstan@bidmc.harvard.edu///contact_department: hem/onc///contact_institute: bidmc///contact_address: 330 brookline av///contact_city: boston///contact_state: MA///contact_zip.postal_code: 2215///contact_country: USA///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM495nnn/GSM495147/GSM495147.CEL.gz///data_row_count: 54675
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

vital_status:
deceased   living
      40       30

}}
\keyword{datasets}
