\name{ GSE32063 }
\alias{ GSE32063 }
\docType{data}
\title{ High-risk ovarian cancer based on 126-gene expression signature is uniquely characterized by downregulation of antigen presentation pathway. }
\description{ High-grade serous ovarian cancers are heterogeneous not only in terms of clinical outcome but also at the molecular level. Our aim was to establish a novel risk classification system based on a gene expression signature for predicting overall survival, leading to suggesting novel therapeutic strategies for high-risk patients.In this large-scale cross-platform study of six microarray data sets consisting of 1,054 ovarian cancer patients, we developed a gene expression signature for predicting overall survival by applying elastic net and 10-fold cross-validation to a Japanese data set A (n = 260) and evaluated the signature in five other data sets. Subsequently, we investigated differences in the biological characteristics between high- and low-risk ovarian cancer groups.An elastic net analysis identified a 126-gene expression signature for predicting overall survival in patients with ovarian cancer using the Japanese data set A (multivariate analysis, P = 4 ?? 10(-20)). We validated its predictive ability with five other data sets using multivariate analysis (Tothill's data set, P = 1 ?? 10(-5); Bonome's data set, P = 0.0033; Dressman's data set, P = 0.0016; TCGA data set, P = 0.0027; Japanese data set B, P = 0.021). Through gene ontology and pathway analyses, we identified a significant reduction in expression of immune-response-related genes, especially on the antigen presentation pathway, in high-risk ovarian cancer patients.This risk classification based on the 126-gene expression signature is an accurate predictor of clinical outcome in patients with advanced stage high-grade serous ovarian cancer and has the potential to develop new therapeutic strategies for high-grade serous ovarian cancer patients. }
\value{An expression set}
\format{
\preformatted{
experimentData(eset):
Experiment data
  Experimenter name: Yoshihara K, Tsunoda T, Shigemizu D, Fujiwara H et al. High-risk ovarian cancer based on 126-gene expression signature is uniquely characterized by downregulation of antigen presentation pathway. Clin Cancer Res 2012 Mar 1;18(5):1374-85.
  Laboratory: Yoshihara, Tanaka 2012
  Contact information:
  Title: High-risk ovarian cancer based on 126-gene expression signature is uniquely characterized by downregulation of antigen presentation pathway.
  URL:
  PMIDs: 22241791

  Abstract: A 255 word abstract is available. Use 'abstract' method.
  Information is available on: preprocessing
  notes:
   platform_title:
      Agilent-014850 Whole Human Genome Microarray 4x44K G4112F (Probe Name vers
ion)
   platform_shorttitle:
      Agilent G4112F
   platform_summary:
      hgug4112a
   platform_manufacturer:
      Agilent
   platform_distribution:
      commercial
   platform_accession:
      GPL6480
   version:
      2015-09-22 19:58:23

featureData(eset):
An object of class 'AnnotatedDataFrame'
  featureNames: A_23_P100001 A_23_P100011 ... A_32_P99902 (30936 total)
  varLabels: probeset gene EntrezGene.ID best_probe
  varMetadata: labelDescription

}}
\details{
\preformatted{
assayData: 30936 features, 40 samples
Platform type:
Overall survival time-to-event summary (in years):
Call: survfit(formula = Surv(time, cens) ~ -1)

      n  events  median 0.95LCL 0.95UCL
  40.00   22.00    4.44    3.29      NA

---------------------------
Available sample meta-data:
---------------------------

alt_sample_name:
 106  108 109R  110 111R  192 195R  196  197  198  200  203  205  206  207  213
   1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
 222  224  226  229  230  231  274  277  278  280  281  282  283  284  285  286
   1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
 287  288  289  291  292  294 297R 298R
   1    1    1    1    1    1    1    1

sample_type:
tumor
   40

histological_type:
ser
 40

summarygrade:
high  low
  17   23

summarystage:
late
  40

tumorstage:
 3  4
31  9

substage:
   b    c NA's
   3   28    9

grade:
 2  3
23 17

pltx:
 y
40

tax:
 y
40

days_to_death:
   Min. 1st Qu.  Median    Mean 3rd Qu.    Max.
    210     705    1155    1346    1792    3330

vital_status:
deceased   living
      22       18

debulking:
   optimal suboptimal
        19         21

uncurated_author_metadata:
  title: serous ovarian cancer 106///geo_accession: GSM795125///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 15///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 26///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795125/GSM795125_s106.txt.gz///data_row_count: 41093///relation: Reanalysis of: GSM432223
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
     title: serous ovarian cancer 108///geo_accession: GSM795126///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIb///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 37///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 37///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795126/GSM795126_s108.txt.gz///data_row_count: 41093///relation: Reanalysis of: GSM432225
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
 title: serous ovarian cancer 109R///geo_accession: GSM795127///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 7///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 20///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795127/GSM795127_s109R.txt.gz///data_row_count: 41093///relation: Reanalysis of: GSM432226
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
  title: serous ovarian cancer 110///geo_accession: GSM795128///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 97///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 97///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795128/GSM795128_s110.txt.gz///data_row_count: 41093///relation: Reanalysis of: GSM432228
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
title: serous ovarian cancer 111R///geo_accession: GSM795129///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 18///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 57///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795129/GSM795129_s111R.txt.gz///data_row_count: 41093///relation: Reanalysis of: GSM432229
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 192///geo_accession: GSM795130///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 20///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 27///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795130/GSM795130_s192.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                           title: serous ovarian cancer 195R///geo_accession: GSM795131///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 6///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 40///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795131/GSM795131_s195R.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                               title: serous ovarian cancer 196///geo_accession: GSM795132///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 28///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 37///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795132/GSM795132_s196.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 197///geo_accession: GSM795133///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIb///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 47///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 47///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795133/GSM795133_s197.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                           title: serous ovarian cancer 198///geo_accession: GSM795134///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 8///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 24///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795134/GSM795134_s198.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                           title: serous ovarian cancer 200///geo_accession: GSM795135///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 6///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 27///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795135/GSM795135_s200.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 203///geo_accession: GSM795136///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 26///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 46///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795136/GSM795136_s203.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                            title: serous ovarian cancer 205///geo_accession: GSM795137///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 43///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 78///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795137/GSM795137_s205.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 206///geo_accession: GSM795138///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 21///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 87///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795138/GSM795138_s206.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 207///geo_accession: GSM795139///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 30///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 30///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795139/GSM795139_s207.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                            title: serous ovarian cancer 213///geo_accession: GSM795140///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 15///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 35///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795140/GSM795140_s213.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 222///geo_accession: GSM795141///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 12///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 12///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795141/GSM795141_s222.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 224///geo_accession: GSM795142///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 11///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 16///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795142/GSM795142_s224.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 226///geo_accession: GSM795143///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 11///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 11///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795143/GSM795143_s226.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                               title: serous ovarian cancer 229///geo_accession: GSM795144///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 9///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 9///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795144/GSM795144_s229.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                                 title: serous ovarian cancer 230///geo_accession: GSM795145///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 8///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 8///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795145/GSM795145_s230.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                               title: serous ovarian cancer 231///geo_accession: GSM795146///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 7///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 7///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795146/GSM795146_s231.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                         title: serous ovarian cancer 274///geo_accession: GSM795147///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 35///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 101///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795147/GSM795147_s274.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                            title: serous ovarian cancer 277///geo_accession: GSM795148///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 73///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 109///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795148/GSM795148_s277.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                            title: serous ovarian cancer 278///geo_accession: GSM795149///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 16///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 21///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795149/GSM795149_s278.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 280///geo_accession: GSM795150///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 68///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 68///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795150/GSM795150_s280.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                           title: serous ovarian cancer 281///geo_accession: GSM795151///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 8///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 15///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795151/GSM795151_s281.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 282///geo_accession: GSM795152///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 82///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 82///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795152/GSM795152_s282.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 283///geo_accession: GSM795153///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 12///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 49///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795153/GSM795153_s283.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                        title: serous ovarian cancer 284///geo_accession: GSM795154///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 111///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 111///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795154/GSM795154_s284.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 285///geo_accession: GSM795155///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 82///characteristics_ch1.7: rec (1): 0///characteristics_ch1.8: os (m): 82///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795155/GSM795155_s285.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                              title: serous ovarian cancer 286///geo_accession: GSM795156///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 8///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 22///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795156/GSM795156_s286.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 287///geo_accession: GSM795157///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 12///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 40///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795157/GSM795157_s287.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 288///geo_accession: GSM795158///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 9///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 24///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795158/GSM795158_s288.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 289///geo_accession: GSM795159///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIb///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 14///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 40///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795159/GSM795159_s289.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 291///geo_accession: GSM795160///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 15///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 48///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795160/GSM795160_s291.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 292///geo_accession: GSM795161///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 28///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 54///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795161/GSM795161_s292.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                             title: serous ovarian cancer 294///geo_accession: GSM795162///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 3///characteristics_ch1.2: Stage: IIIc///characteristics_ch1.3: surgery status: optimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 49///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 70///characteristics_ch1.9: death (1): 0///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795162/GSM795162_s294.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                           title: serous ovarian cancer 297R///geo_accession: GSM795163///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 2///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 24///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795163/GSM795163_s297R.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1
                          title: serous ovarian cancer 298R///geo_accession: GSM795164///status: Public on Mar 01 2012///submission_date: Sep 12 2011///last_update_date: Mar 01 2012///type: RNA///channel_count: 1///source_name_ch1: high-grade serous ovarian cancer///organism_ch1: Homo sapiens///characteristics_ch1: tissue: tumor///characteristics_ch1.1: grading: 2///characteristics_ch1.2: Stage: IV///characteristics_ch1.3: surgery status: suboptimal///characteristics_ch1.4: taxane: 1///characteristics_ch1.5: platinum: 1///characteristics_ch1.6: pfs (m): 31///characteristics_ch1.7: rec (1): 1///characteristics_ch1.8: os (m): 57///characteristics_ch1.9: death (1): 1///molecule_ch1: total RNA///extract_protocol_ch1: Total RNA was extracted from tissue samples using TRIzol reagent (Invitrogen, Carlsbad, CA, USA) following the manufacturer's recommendations. RNA was examined with a 2100 Bioanalyzer (Agilent Technologies Inc., Palo Alto, CA, USA) using an RNA 6000 Nano LabChip (Agilent Technologies)///label_ch1: Cy3///label_protocol_ch1: Cyanine-3 (Cy3) labeled cRNA was prepared from 0.5 ug RNA using the Quick Amp Labering Kit, one-color (Agilent Technologies) according to the manufacturer's instructions, followed by RNAeasy column purification (QIAGEN, Valencia, CA).///taxid_ch1: 9606///hyb_protocol: Cy3-labeled cRNAs (1.65 g) were hybridized for 17 hours at 65C to an Agilent Whole Human Genome Oligo Microarray in a rotating Agilent hybridization oven.///scan_protocol: The hybridized microarray was washed and then scanned in Cy3 channel with the Agilent DNA Microarray Scanner (model G2565AA).///data_processing: Signal intensity per spot was generated from the scanned image with Feature Extraction Software ver.9.1 (Agilent Technologies) in the default settings.///platform_id: GPL6480///contact_name: Kosuke,,Yoshihara///contact_email: yoshikou@med.niigata-u.ac.jp///contact_department: Obstetrics and Gynecology///contact_institute: Niigata University///contact_address: 1-757 Asahimachi-dori///contact_city: Niigata///contact_zip.postal_code: 951-8510///contact_country: Japan///supplementary_file: ftp://ftp.ncbi.nih.gov/pub/geo/DATA/supplementary/samples/GSM795nnn/GSM795164/GSM795164_s298R.txt.gz///data_row_count: 41093///relation:
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      1

}}
\keyword{datasets}
